==> nmrium-0.50.1.tgz: package/lib/component/2d/1d-tracer/phase-correction-traces/SpectraPhaseTraces.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useChartData } from '../../../context/ChartContext';
import { HighlightEventSource, useHighlight } from '../../../highlight';
import { useScale2DX, useScale2DY } from '../../utilities/scale';
import { SpectrumPhaseTrace } from './SpectrumPhaseTrace';
import { useActivePhaseTraces } from './useActivePhaseTraces';
const BOX_SIZE = 20;
const style = css `
  .target {
    fill: transparent;
  }

  &:hover {
    .target {
      fill: #ff6f0057;
    }
  }
`;
export function SpectraPhaseTraces() {
    const { width, height } = useChartData();
    const { spectra = [], color, activeTraceDirection } = useActivePhaseTraces();
    if (!width || !height || spectra.length === 0) {
        return null;
    }
    return spectra.map((spectrumTrace) => {
        return (_jsx(PhaseTrace, { spectrum: spectrumTrace, color: color, direction: activeTraceDirection }, spectrumTrace.id));
    });
}
function PhaseTrace(props) {
    const { width, height, margin } = useChartData();
    const { spectrum: { data, x, y, id }, color, direction, } = props;
    const highligh = useHighlight([id], {
        type: HighlightEventSource.PHASE_CORRECTION_TRACE,
        extra: { id },
    });
    const scale2dX = useScale2DX();
    const scale2dY = useScale2DY();
    const innerheight = height - margin.top - margin.bottom;
    const innerWidth = width - margin.left - margin.right;
    const transformY = innerheight - BOX_SIZE / 2;
    const transformX = innerWidth - BOX_SIZE / 2;
    return (_jsxs(SpectrumPhaseTrace, { data: data, position: { x: scale2dX(x), y: scale2dY(y) }, color: color, direction: direction, ...highligh.onHover, css: style, children: [direction === 'horizontal' && (_jsx("rect", { className: "target", y: transformY, x: margin.left, width: `${innerWidth}px`, height: `${BOX_SIZE}px` })), direction === 'vertical' && (_jsx("rect", { className: "target", y: margin.top, x: transformX, width: `${BOX_SIZE}px`, height: innerheight }))] }));
}

==> nmrium-0.53.0.tgz: package/lib/component/2d/1d-tracer/phase-correction-traces/SpectraPhaseTraces.js <==
import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
/** @jsxImportSource @emotion/react */
import { css } from '@emotion/react';
import { useChartData } from '../../../context/ChartContext';
import { HighlightEventSource, useHighlight } from '../../../highlight';
import { SpectrumPhaseTrace } from './SpectrumPhaseTrace';
import { useActivePhaseTraces } from './useActivePhaseTraces';
const BOX_SIZE = 20;
const style = css `
  fill: transparent;

  &:hover {
    fill: #ff6f0057;
  }
`;
export function SpectraPhaseTraces() {
    const { spectra = [], color, activeTraceDirection } = useActivePhaseTraces();
    return spectra.map((spectrumTrace) => {
        return (_jsx(PhaseTrace, { spectrum: spectrumTrace, color: color, direction: activeTraceDirection }, spectrumTrace.id));
    });
}
function PhaseTrace(props) {
    const { width, height, margin } = useChartData();
    const { spectrum: { x, y, id }, direction, } = props;
    const highligh = useHighlight([id], {
        type: HighlightEventSource.PHASE_CORRECTION_TRACE,
        extra: { id },
    });
    const innerHeight = height - margin.top - margin.bottom;
    const innerWidth = width - margin.left - margin.right;
    const transformY = innerHeight - BOX_SIZE / 2;
    const transformX = innerWidth - BOX_SIZE / 2;
    return (_jsxs(SpectrumPhaseTrace, { positionUnit: "PPM", position: { x, y }, ...highligh.onHover, children: [direction === 'horizontal' && (_jsx("rect", { css: style, y: transformY, x: margin.left, width: `${innerWidth}px`, height: `${BOX_SIZE}px` })), direction === 'vertical' && (_jsx("rect", { css: style, y: margin.top, x: transformX, width: `${BOX_SIZE}px`, height: innerHeight }))] }));
}
